matminer package — matminer 0.1.3 documentation

# matminer package

## Subpackages

- matminer.data_retrieval package
  - Submodules
  - matminer.data_retrieval.retrieve_Citrine module
  - matminer.data_retrieval.retrieve_MP module
  - matminer.data_retrieval.retrieve_MPDS module
  - matminer.data_retrieval.retrieve_MongoDB module
  - Module contents
- matminer.datasets package
  - Subpackages
    - matminer.datasets.test_datasets package
      - Submodules
      - matminer.datasets.test_datasets.test_datasets module
      - Module contents
  - Submodules
  - matminer.datasets.dataframe_loader module
  - Module contents
- matminer.featurizers package
  - Subpackages
    - matminer.featurizers.data_files package
      - Submodules
      - matminer.featurizers.data_files.deml_elementdata module
      - Module contents
  - Submodules
  - matminer.featurizers.bandstructure module
  - matminer.featurizers.base module
  - matminer.featurizers.composition module
  - matminer.featurizers.data module
  - matminer.featurizers.site module
  - matminer.featurizers.stats module
  - matminer.featurizers.structure module
  - Module contents
- matminer.figrecipes package
  - Subpackages
    - matminer.figrecipes.matplotlib package
      - Subpackages
        - matminer.figrecipes.matplotlib.examples package
          - Submodules
          - matminer.figrecipes.matplotlib.examples.heatmap_examples module
          - matminer.figrecipes.matplotlib.examples.xyscatter_examples module
          - Module contents
      - Submodules
      - matminer.figrecipes.matplotlib.plots module
      - Module contents
    - matminer.figrecipes.plotly package
      - Submodules
      - matminer.figrecipes.plotly.make_plots module
      - Module contents
  - Module contents
- matminer.learners package
  - Subpackages
    - matminer.learners.tests package
      - Submodules
      - matminer.learners.tests.test_volume_predictor module
      - Module contents
  - Submodules
  - matminer.learners.volume_predictor module
  - Module contents
- matminer.models package
  - Submodules
  - matminer.models.mechanical_properties module
  - matminer.models.sound_velocity module
  - matminer.models.thermal_conductivity module
  - Module contents

## Submodules

## matminer.decorate module

## matminer.pyCookieCheat module

## matminer.utils module

`matminer.utils.` `flattenDict`(d, result=None)

  Function to flatten a JSON dictionary. Taken from: https://gist.github.com/higarmi/6708779

  example: The following JSON document: {“maps”:[{“id1”:”blabla”,”iscategorical1”:”0”, “perro”:[{“dog1”: “1”, “dog2”: “2”}]},{“id2”:”blabla”,”iscategorical2”:”0”}], “masks”:{“id”:”valore”}, “om_points”:”value”, “parameters”:{“id”:”valore”}}

  will have the following output: {‘masks.id’: ‘valore’, ‘maps.iscategorical2’: ‘0’, ‘om_points’: ‘value’, ‘maps.iscategorical1’: ‘0’, ‘maps.id1’: ‘blabla’, ‘parameters.id’: ‘valore’, ‘maps.perro.dog2’: ‘2’, ‘maps.perro.dog1’: ‘1’, ‘maps.id2’: ‘blabla’}

## Module contents